@@ -1,18 +1,21 @@
 #!/usr/bin/python
 #
-# Copyright 2012 Software Freedom Conservancy
+# Licensed to the Software Freedom Conservancy (SFC) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The SFC licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
 #
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
+#   http://www.apache.org/licenses/LICENSE-2.0
 #
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
 import platform
 import signal
 import subprocess
@@ -72,7 +75,7 @@ class Service(object):
                                             stdout=self._log, stderr=self._log)
 
         except Exception as e:
-            raise WebDriverException("Unable to start phantomjs with ghostdriver.", e)
+            raise WebDriverException("Unable to start phantomjs with ghostdriver: %s" % e)
         count = 0
         while not utils.is_connectable(self.port):
             count += 1
@@ -101,7 +104,8 @@ class Service(object):
         #Tell the Server to properly die in case
         try:
             if self.process:
-                self.process.send_signal(signal.SIGTERM)
+                self.process.stdin.close()
+                self.process.kill()
                 self.process.wait()
         except OSError:
             # kill may not be available under windows environment
