@@ -1,17 +1,21 @@
-# Copyright 2010 WebDriver committers
-# Copyright 2010 Google Inc.
+#!/usr/bin/python
 #
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
+# Licensed to the Software Freedom Conservancy (SFC) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The SFC licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
 #
-#     http://www.apache.org/licenses/LICENSE-2.0
+#   http://www.apache.org/licenses/LICENSE-2.0
 #
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
 
 class Command(object):
     """
@@ -21,7 +25,8 @@ class Command(object):
     used to marshal commands through a service that implements WebDriver's
     remote wire protocol:
 
-        http://code.google.com/p/selenium/wiki/JsonWireProtocol
+        https://github.com/SeleniumHQ/selenium/wiki/JsonWireProtocol
+
     """
 
     # Keep in sync with org.openqa.selenium.remote.DriverCommand
@@ -125,9 +130,6 @@ class Command(object):
     GET_APP_CACHE_STATUS = "getAppCacheStatus"
     CLEAR_APP_CACHE = "clearAppCache"
 
-    GET_NETWORK_CONNECTION = "getNetworkConnection"
-    SET_NETWORK_CONNECTION = "setNetworkConnection"
-
     GET_LOCAL_STORAGE_ITEM = "getLocalStorageItem"
     REMOVE_LOCAL_STORAGE_ITEM = "removeLocalStorageItem"
     GET_LOCAL_STORAGE_KEYS = "getLocalStorageKeys"
@@ -141,3 +143,10 @@ class Command(object):
     SET_SESSION_STORAGE_ITEM = "setSessionStorageItem"
     CLEAR_SESSION_STORAGE = "clearSessionStorage"
     GET_SESSION_STORAGE_SIZE = "getSessionStorageSize"
+    
+    # Mobile
+    GET_NETWORK_CONNECTION = "getNetworkConnection"
+    SET_NETWORK_CONNECTION = "setNetworkConnection"
+    CURRENT_CONTEXT_HANDLE = "getCurrentContextHandle"
+    CONTEXT_HANDLES = "getContextHandles"
+    SWITCH_TO_CONTEXT = "switchToContext"
