@@ -1,16 +1,21 @@
-# Copyright 2008-2013 Software Freedom Conservancy
+#!/usr/bin/python
 #
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
+# Licensed to the Software Freedom Conservancy (SFC) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The SFC licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
 #
-#     http://www.apache.org/licenses/LICENSE-2.0
+#   http://www.apache.org/licenses/LICENSE-2.0
 #
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
 
 import logging
 import socket
@@ -126,12 +131,10 @@ class HttpErrorHandler(url_request.HTTPDefaultErrorHandler):
 
 
 class RemoteConnection(object):
-    """
-    A connection with the Remote WebDriver server.
+    """A connection with the Remote WebDriver server.
 
     Communicates with the server using the WebDriver wire protocol:
-    http://code.google.com/p/selenium/wiki/JsonWireProtocol
-    """
+    https://github.com/SeleniumHQ/selenium/wiki/JsonWireProtocol"""
     def __init__(self, remote_server_addr, keep_alive=False):
         # Attempt to resolve the hostname and get an IP address.
         self.keep_alive = keep_alive
@@ -327,6 +330,12 @@ class RemoteConnection(object):
                 ('POST', '/session/$sessionId/log'),
             Command.GET_AVAILABLE_LOG_TYPES:
                 ('GET', '/session/$sessionId/log/types'),
+            Command.CURRENT_CONTEXT_HANDLE:
+                ('GET', '/session/$sessionId/context'),
+            Command.CONTEXT_HANDLES:
+                ('GET', '/session/$sessionId/contexts'),
+            Command.SWITCH_TO_CONTEXT:
+                ('POST', '/session/$sessionId/context'),
         }
 
     def execute(self, command, params):
