@@ -1,18 +1,21 @@
 #!/usr/bin/python
-
-# Copyright 2011 Software Freedom Conservancy.
 #
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
+# Licensed to the Software Freedom Conservancy (SFC) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The SFC licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
 #
-#     http://www.apache.org/licenses/LICENSE-2.0
+#   http://www.apache.org/licenses/LICENSE-2.0
 #
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
 
 RGB_PATTERN = r"^\s*rgb\(\s*(\d{1,3})\s*,\s*(\d{1,3})\s*,\s*(\d{1,3})\s*\)\s*$"
 RGB_PCT_PATTERN = r"^\s*rgb\(\s*(\d{1,3}|\d{1,2}\.\d+)%\s*,\s*(\d{1,3}|\d{1,2}\.\d+)%\s*,\s*(\d{1,3}|\d{1,2}\.\d+)%\s*\)\s*$"
@@ -113,13 +116,13 @@ class Color(object):
             g = hue_to_rgb(luminocity1, luminocity2, h)
             b = hue_to_rgb(luminocity1, luminocity2, h - 1.0 / 3.0)
 
-        return Color(r * 256, g * 256, b * 256, a)
+        return Color(round(r * 255), round(g * 255), round(b * 255), a)
 
     def __init__(self, red, green, blue, alpha=1):
         self.red = int(red)
         self.green = int(green)
         self.blue = int(blue)
-        self.alpha = float(alpha) or 0
+        self.alpha = "1" if float(alpha) == 1 else str(float(alpha) or 0)
 
     @property
     def rgb(self):
@@ -127,8 +130,7 @@ class Color(object):
 
     @property
     def rgba(self):
-        a = "1" if self.alpha == 1 else str(self.alpha)
-        return "rgba(%d, %d, %d, %s)" % (self.red, self.green, self.blue, a)
+        return "rgba(%d, %d, %d, %s)" % (self.red, self.green, self.blue, self.alpha)
 
     @property
     def hex(self):
@@ -148,6 +150,12 @@ class Color(object):
     def __hash__(self):
         return hash((self.red, self.green, self.blue, self.alpha))
 
+    def __repr__(self):
+        return "Color(red=%d, green=%d, blue=%d, alpha=%s)" % (self.red, self.green, self.blue, self.alpha)
+
+    def __str__(self):
+        return "Color: %s" % self.rgba
+
 
 # Basic, extended and transparent colour keywords as defined by the W3C HTML4 spec
 # See http://www.w3.org/TR/css3-color/#html4
