@@ -1,18 +1,21 @@
 #!/usr/bin/python
 #
-# Copyright 2011 Software Freedom Conservancy.
+# Licensed to the Software Freedom Conservancy (SFC) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The SFC licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
 #
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
+#   http://www.apache.org/licenses/LICENSE-2.0
 #
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
 
 from selenium.webdriver.common.by import By
 from selenium.common.exceptions import NoSuchElementException, UnexpectedTagNameException
@@ -121,19 +124,18 @@ class Select:
         if len(opts) == 0 and " " in text:
             subStringWithoutSpace = self._get_longest_token(text)
             if subStringWithoutSpace == "":
-                # seems weird to me that the java impl just selects the first or all if multiple
-                # oh well... doing it here too.
                 candidates = self.options
             else:
                 xpath = ".//option[contains(.,%s)]" % self._escapeString(subStringWithoutSpace)
                 candidates = self._el.find_elements(By.XPATH, xpath)
             for candidate in candidates:
-                self._setSelected(candidate)
-                if not self.is_multiple:
-                    return
-                matched = True
+                if text == candidate.text:
+                    self._setSelected(candidate)
+                    if not self.is_multiple:
+                        return
+                    matched = True
 
-        if matched != True:
+        if not matched:
             raise NoSuchElementException("Could not locate element with visible text: %s" % text)
 
     def deselect_all(self):
